@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-'''
+"""
 Manage users on Mac OS 10.7+
 
 .. important::
@@ -7,21 +7,14 @@ Manage users on Mac OS 10.7+
     minion, and it is using a different module (or gives an error similar to
     *'user.info' is not available*), see :ref:`here
     <module-provider-override>`.
-'''
+"""
 
 # Import python libs
-from __future__ import absolute_import, unicode_literals, print_function
-try:
-    import pwd
-except ImportError:
-    pass
+from __future__ import absolute_import, print_function, unicode_literals
+
 import logging
 import time
 
-# Import 3rdp-party libs
-from salt.ext.six.moves import range, map  # pylint: disable=import-error,redefined-builtin
-from salt.ext.six import string_types
-
 # Import salt libs
 import salt.utils.args
 import salt.utils.data
@@ -29,46 +22,54 @@ import salt.utils.decorators.path
 import salt.utils.files
 import salt.utils.stringutils
 import salt.utils.user
-from salt.utils.locales import sdecode as _sdecode
 from salt.exceptions import CommandExecutionError, SaltInvocationError
 from salt.ext import six
+from salt.ext.six import string_types
+
+# Import 3rdp-party libs
+from salt.ext.six.moves import map, range
+
+try:
+    import pwd
+except ImportError:
+    pass
+
 
 log = logging.getLogger(__name__)
 
 # Define the module's virtual name
-__virtualname__ = 'user'
+__virtualname__ = "user"
 
 
 def __virtual__():
-    if (__grains__.get('kernel') != 'Darwin' or
-            __grains__['osrelease_info'] < (10, 7)):
-        return False
+    if __grains__.get("kernel") != "Darwin" or __grains__["osrelease_info"] < (10, 7):
+        return (False, "Only available on Mac OS 10.7+ systems")
     else:
         return __virtualname__
 
 
 def _flush_dscl_cache():
-    '''
+    """
     Flush dscl cache
-    '''
-    __salt__['cmd.run'](['dscacheutil', '-flushcache'], python_shell=False)
+    """
+    __salt__["cmd.run"](["dscacheutil", "-flushcache"], python_shell=False)
 
 
-def _dscl(cmd, ctype='create'):
-    '''
+def _dscl(cmd, ctype="create"):
+    """
     Run a dscl -create command
-    '''
-    if __grains__['osrelease_info'] < (10, 8):
-        source, noderoot = '.', ''
+    """
+    if __grains__["osrelease_info"] < (10, 8):
+        source, noderoot = ".", ""
     else:
-        source, noderoot = 'localhost', '/Local/Default'
+        source, noderoot = "localhost", "/Local/Default"
     if noderoot:
         cmd[0] = noderoot + cmd[0]
 
-    return __salt__['cmd.run_all'](
-        ['dscl', source, '-' + ctype] + cmd,
-        output_loglevel='quiet' if ctype == 'passwd' else 'debug',
-        python_shell=False
+    return __salt__["cmd.run_all"](
+        ["dscl", source, "-" + ctype] + cmd,
+        output_loglevel="quiet" if ctype == "passwd" else "debug",
+        python_shell=False,
     )
 
 
@@ -79,16 +80,18 @@ def _first_avail_uid():
             return idx
 
 
-def add(name,
-        uid=None,
-        gid=None,
-        groups=None,
-        home=None,
-        shell=None,
-        fullname=None,
-        createhome=True,
-        **kwargs):
-    '''
+def add(
+    name,
+    uid=None,
+    gid=None,
+    groups=None,
+    home=None,
+    shell=None,
+    fullname=None,
+    createhome=True,
+    **kwargs
+):
+    """
     Add a user to the minion
 
     CLI Example:
@@ -96,39 +99,39 @@ def add(name,
     .. code-block:: bash
 
         salt '*' user.add name <uid> <gid> <groups> <home> <shell>
-    '''
+    """
     if info(name):
-        raise CommandExecutionError('User \'{0}\' already exists'.format(name))
+        raise CommandExecutionError("User '{0}' already exists".format(name))
 
     if salt.utils.stringutils.contains_whitespace(name):
-        raise SaltInvocationError('Username cannot contain whitespace')
+        raise SaltInvocationError("Username cannot contain whitespace")
 
     if uid is None:
         uid = _first_avail_uid()
     if gid is None:
         gid = 20  # gid 20 == 'staff', the default group
     if home is None:
-        home = '/Users/{0}'.format(name)
+        home = "/Users/{0}".format(name)
     if shell is None:
-        shell = '/bin/bash'
+        shell = "/bin/bash"
     if fullname is None:
-        fullname = ''
+        fullname = ""
 
     if not isinstance(uid, int):
-        raise SaltInvocationError('uid must be an integer')
+        raise SaltInvocationError("uid must be an integer")
     if not isinstance(gid, int):
-        raise SaltInvocationError('gid must be an integer')
+        raise SaltInvocationError("gid must be an integer")
 
-    name_path = '/Users/{0}'.format(name)
-    _dscl([name_path, 'UniqueID', uid])
-    _dscl([name_path, 'PrimaryGroupID', gid])
-    _dscl([name_path, 'UserShell', shell])
-    _dscl([name_path, 'NFSHomeDirectory', home])
-    _dscl([name_path, 'RealName', fullname])
+    name_path = "/Users/{0}".format(name)
+    _dscl([name_path, "UniqueID", uid])
+    _dscl([name_path, "PrimaryGroupID", gid])
+    _dscl([name_path, "UserShell", shell])
+    _dscl([name_path, "NFSHomeDirectory", home])
+    _dscl([name_path, "RealName", fullname])
 
     # Make sure home directory exists
     if createhome:
-        __salt__['file.mkdir'](home, user=uid, group=gid)
+        __salt__["file.mkdir"](home, user=uid, group=gid)
 
     # dscl buffers changes, sleep before setting group membership
     time.sleep(1)
@@ -138,7 +141,7 @@ def add(name,
 
 
 def delete(name, remove=False, force=False):
-    '''
+    """
     Remove a user from the minion
 
     CLI Example:
@@ -146,29 +149,29 @@ def delete(name, remove=False, force=False):
     .. code-block:: bash
 
         salt '*' user.delete name remove=True force=True
-    '''
+    """
     if salt.utils.stringutils.contains_whitespace(name):
-        raise SaltInvocationError('Username cannot contain whitespace')
+        raise SaltInvocationError("Username cannot contain whitespace")
     if not info(name):
         return True
 
     # force is added for compatibility with user.absent state function
     if force:
-        log.warning('force option is unsupported on MacOS, ignoring')
+        log.warning("force option is unsupported on MacOS, ignoring")
 
     # remove home directory from filesystem
     if remove:
-        __salt__['file.remove'](info(name)['home'])
+        __salt__["file.remove"](info(name)["home"])
 
     # Remove from any groups other than primary group. Needs to be done since
     # group membership is managed separately from users and an entry for the
     # user will persist even after the user is removed.
     chgroups(name, ())
-    return _dscl(['/Users/{0}'.format(name)], ctype='delete')['retcode'] == 0
+    return _dscl(["/Users/{0}".format(name)], ctype="delete")["retcode"] == 0
 
 
 def getent(refresh=False):
-    '''
+    """
     Return the list of all info for all users
 
     CLI Example:
@@ -176,19 +179,19 @@ def getent(refresh=False):
     .. code-block:: bash
 
         salt '*' user.getent
-    '''
-    if 'user.getent' in __context__ and not refresh:
-        return __context__['user.getent']
+    """
+    if "user.getent" in __context__ and not refresh:
+        return __context__["user.getent"]
 
     ret = []
     for data in pwd.getpwall():
         ret.append(_format_info(data))
-    __context__['user.getent'] = ret
+    __context__["user.getent"] = ret
     return ret
 
 
 def chuid(name, uid):
-    '''
+    """
     Change the uid for a named user
 
     CLI Example:
@@ -196,26 +199,23 @@ def chuid(name, uid):
     .. code-block:: bash
 
         salt '*' user.chuid foo 4376
-    '''
+    """
     if not isinstance(uid, int):
-        raise SaltInvocationError('uid must be an integer')
+        raise SaltInvocationError("uid must be an integer")
     pre_info = info(name)
     if not pre_info:
-        raise CommandExecutionError('User \'{0}\' does not exist'.format(name))
-    if uid == pre_info['uid']:
+        raise CommandExecutionError("User '{0}' does not exist".format(name))
+    if uid == pre_info["uid"]:
         return True
-    _dscl(
-        ['/Users/{0}'.format(name), 'UniqueID', pre_info['uid'], uid],
-        ctype='change'
-    )
+    _dscl(["/Users/{0}".format(name), "UniqueID", pre_info["uid"], uid], ctype="change")
     # dscl buffers changes, sleep 1 second before checking if new value
     # matches desired value
     time.sleep(1)
-    return info(name).get('uid') == uid
+    return info(name).get("uid") == uid
 
 
 def chgid(name, gid):
-    '''
+    """
     Change the default group of the user
 
     CLI Example:
@@ -223,26 +223,26 @@ def chgid(name, gid):
     .. code-block:: bash
 
         salt '*' user.chgid foo 4376
-    '''
+    """
     if not isinstance(gid, int):
-        raise SaltInvocationError('gid must be an integer')
+        raise SaltInvocationError("gid must be an integer")
     pre_info = info(name)
     if not pre_info:
-        raise CommandExecutionError('User \'{0}\' does not exist'.format(name))
-    if gid == pre_info['gid']:
+        raise CommandExecutionError("User '{0}' does not exist".format(name))
+    if gid == pre_info["gid"]:
         return True
     _dscl(
-        ['/Users/{0}'.format(name), 'PrimaryGroupID', pre_info['gid'], gid],
-        ctype='change'
+        ["/Users/{0}".format(name), "PrimaryGroupID", pre_info["gid"], gid],
+        ctype="change",
     )
     # dscl buffers changes, sleep 1 second before checking if new value
     # matches desired value
     time.sleep(1)
-    return info(name).get('gid') == gid
+    return info(name).get("gid") == gid
 
 
 def chshell(name, shell):
-    '''
+    """
     Change the default shell of the user
 
     CLI Example:
@@ -250,24 +250,24 @@ def chshell(name, shell):
     .. code-block:: bash
 
         salt '*' user.chshell foo /bin/zsh
-    '''
+    """
     pre_info = info(name)
     if not pre_info:
-        raise CommandExecutionError('User \'{0}\' does not exist'.format(name))
-    if shell == pre_info['shell']:
+        raise CommandExecutionError("User '{0}' does not exist".format(name))
+    if shell == pre_info["shell"]:
         return True
     _dscl(
-        ['/Users/{0}'.format(name), 'UserShell', pre_info['shell'], shell],
-        ctype='change'
+        ["/Users/{0}".format(name), "UserShell", pre_info["shell"], shell],
+        ctype="change",
     )
     # dscl buffers changes, sleep 1 second before checking if new value
     # matches desired value
     time.sleep(1)
-    return info(name).get('shell') == shell
+    return info(name).get("shell") == shell
 
 
 def chhome(name, home, **kwargs):
-    '''
+    """
     Change the home directory of the user
 
     CLI Example:
@@ -275,32 +275,31 @@ def chhome(name, home, **kwargs):
     .. code-block:: bash
 
         salt '*' user.chhome foo /Users/foo
-    '''
+    """
     kwargs = salt.utils.args.clean_kwargs(**kwargs)
-    persist = kwargs.pop('persist', False)
+    persist = kwargs.pop("persist", False)
     if kwargs:
         salt.utils.args.invalid_kwargs(kwargs)
     if persist:
-        log.info('Ignoring unsupported \'persist\' argument to user.chhome')
+        log.info("Ignoring unsupported 'persist' argument to user.chhome")
 
     pre_info = info(name)
     if not pre_info:
-        raise CommandExecutionError('User \'{0}\' does not exist'.format(name))
-    if home == pre_info['home']:
+        raise CommandExecutionError("User '{0}' does not exist".format(name))
+    if home == pre_info["home"]:
         return True
     _dscl(
-        ['/Users/{0}'.format(name), 'NFSHomeDirectory',
-         pre_info['home'], home],
-        ctype='change'
+        ["/Users/{0}".format(name), "NFSHomeDirectory", pre_info["home"], home],
+        ctype="change",
     )
     # dscl buffers changes, sleep 1 second before checking if new value
     # matches desired value
     time.sleep(1)
-    return info(name).get('home') == home
+    return info(name).get("home") == home
 
 
 def chfullname(name, fullname):
-    '''
+    """
     Change the user's Full Name
 
     CLI Example:
@@ -308,35 +307,31 @@ def chfullname(name, fullname):
     .. code-block:: bash
 
         salt '*' user.chfullname foo 'Foo Bar'
-    '''
-    if isinstance(fullname, string_types):
-        fullname = _sdecode(fullname)
+    """
+    fullname = salt.utils.data.decode(fullname)
     pre_info = info(name)
     if not pre_info:
-        raise CommandExecutionError('User \'{0}\' does not exist'.format(name))
-    if isinstance(pre_info['fullname'], string_types):
-        pre_info['fullname'] = _sdecode(pre_info['fullname'])
-    if fullname == pre_info['fullname']:
+        raise CommandExecutionError("User '{0}' does not exist".format(name))
+    pre_info["fullname"] = salt.utils.data.decode(pre_info["fullname"])
+    if fullname == pre_info["fullname"]:
         return True
     _dscl(
-        ['/Users/{0}'.format(name), 'RealName', fullname],
+        ["/Users/{0}".format(name), "RealName", fullname],
         # use a 'create' command, because a 'change' command would fail if
         # current fullname is an empty string. The 'create' will just overwrite
         # this field.
-        ctype='create'
+        ctype="create",
     )
     # dscl buffers changes, sleep 1 second before checking if new value
     # matches desired value
     time.sleep(1)
 
-    current = info(name).get('fullname')
-    if isinstance(current, string_types):
-        current = _sdecode(current)
+    current = salt.utils.data.decode(info(name).get("fullname"))
     return current == fullname
 
 
 def chgroups(name, groups, append=False):
-    '''
+    """
     Change the groups to which the user belongs. Note that the user's primary
     group does not have to be one of the groups passed, membership in the
     user's primary group is automatically assumed.
@@ -354,46 +349,42 @@ def chgroups(name, groups, append=False):
     .. code-block:: bash
 
         salt '*' user.chgroups foo wheel,root
-    '''
+    """
     ### NOTE: **args isn't used here but needs to be included in this
     ### function for compatibility with the user.present state
     uinfo = info(name)
     if not uinfo:
-        raise CommandExecutionError('User \'{0}\' does not exist'.format(name))
+        raise CommandExecutionError("User '{0}' does not exist".format(name))
     if isinstance(groups, string_types):
-        groups = groups.split(',')
+        groups = groups.split(",")
 
     bad_groups = [x for x in groups if salt.utils.stringutils.contains_whitespace(x)]
     if bad_groups:
         raise SaltInvocationError(
-            'Invalid group name(s): {0}'.format(', '.join(bad_groups))
+            "Invalid group name(s): {0}".format(", ".join(bad_groups))
         )
     ugrps = set(list_groups(name))
     desired = set(six.text_type(x) for x in groups if bool(six.text_type(x)))
-    primary_group = __salt__['file.gid_to_group'](uinfo['gid'])
+    primary_group = __salt__["file.gid_to_group"](uinfo["gid"])
     if primary_group:
         desired.add(primary_group)
     if ugrps == desired:
         return True
     # Add groups from which user is missing
     for group in desired - ugrps:
-        _dscl(
-            ['/Groups/{0}'.format(group), 'GroupMembership', name],
-            ctype='append'
-        )
+        _dscl(["/Groups/{0}".format(group), "GroupMembership", name], ctype="append")
     if not append:
         # Remove from extra groups
         for group in ugrps - desired:
             _dscl(
-                ['/Groups/{0}'.format(group), 'GroupMembership', name],
-                ctype='delete'
+                ["/Groups/{0}".format(group), "GroupMembership", name], ctype="delete"
             )
     time.sleep(1)
     return set(list_groups(name)) == desired
 
 
 def info(name):
-    '''
+    """
     Return user information
 
     CLI Example:
@@ -401,7 +392,7 @@ def info(name):
     .. code-block:: bash
 
         salt '*' user.info root
-    '''
+    """
     try:
         data = pwd.getpwnam(name)
     except KeyError:
@@ -411,21 +402,23 @@ def info(name):
 
 
 def _format_info(data):
-    '''
+    """
     Return user information in a pretty way
-    '''
-    return {'gid': data.pw_gid,
-            'groups': list_groups(data.pw_name),
-            'home': data.pw_dir,
-            'name': data.pw_name,
-            'shell': data.pw_shell,
-            'uid': data.pw_uid,
-            'fullname': data.pw_gecos}
+    """
+    return {
+        "gid": data.pw_gid,
+        "groups": list_groups(data.pw_name),
+        "home": data.pw_dir,
+        "name": data.pw_name,
+        "shell": data.pw_shell,
+        "uid": data.pw_uid,
+        "fullname": data.pw_gecos,
+    }
 
 
-@salt.utils.decorators.path.which('id')
+@salt.utils.decorators.path.which("id")
 def primary_group(name):
-    '''
+    """
     Return the primary group of the named user
 
     .. versionadded:: 2016.3.0
@@ -435,12 +428,12 @@ def primary_group(name):
     .. code-block:: bash
 
         salt '*' user.primary_group saltadmin
-    '''
-    return __salt__['cmd.run'](['id', '-g', '-n', name])
+    """
+    return __salt__["cmd.run"](["id", "-g", "-n", name])
 
 
 def list_groups(name):
-    '''
+    """
     Return a list of groups the named user belongs to.
 
     name
@@ -456,13 +449,13 @@ def list_groups(name):
     .. code-block:: bash
 
         salt '*' user.list_groups foo
-    '''
+    """
     groups = [group for group in salt.utils.user.get_group_list(name)]
     return groups
 
 
 def list_users():
-    '''
+    """
     Return a list of all users
 
     CLI Example:
@@ -470,13 +463,13 @@ def list_users():
     .. code-block:: bash
 
         salt '*' user.list_users
-    '''
-    users = _dscl(['/users'], 'list')['stdout']
+    """
+    users = _dscl(["/users"], "list")["stdout"]
     return users.split()
 
 
 def rename(name, new_name):
-    '''
+    """
     Change the username for a named user
 
     CLI Example:
@@ -484,27 +477,22 @@ def rename(name, new_name):
     .. code-block:: bash
 
         salt '*' user.rename name new_name
-    '''
+    """
     current_info = info(name)
     if not current_info:
-        raise CommandExecutionError('User \'{0}\' does not exist'.format(name))
+        raise CommandExecutionError("User '{0}' does not exist".format(name))
     new_info = info(new_name)
     if new_info:
-        raise CommandExecutionError(
-            'User \'{0}\' already exists'.format(new_name)
-        )
-    _dscl(
-        ['/Users/{0}'.format(name), 'RecordName', name, new_name],
-        ctype='change'
-    )
+        raise CommandExecutionError("User '{0}' already exists".format(new_name))
+    _dscl(["/Users/{0}".format(name), "RecordName", name, new_name], ctype="change")
     # dscl buffers changes, sleep 1 second before checking if new value
     # matches desired value
     time.sleep(1)
-    return info(new_name).get('RecordName') == new_name
+    return info(new_name).get("RecordName") == new_name
 
 
 def get_auto_login():
-    '''
+    """
     .. versionadded:: 2016.3.0
 
     Gets the current setting for Auto Login
@@ -517,17 +505,19 @@ def get_auto_login():
     .. code-block:: bash
 
         salt '*' user.get_auto_login
-    '''
-    cmd = ['defaults',
-           'read',
-           '/Library/Preferences/com.apple.loginwindow.plist',
-           'autoLoginUser']
-    ret = __salt__['cmd.run_all'](cmd, ignore_retcode=True)
-    return False if ret['retcode'] else ret['stdout']
+    """
+    cmd = [
+        "defaults",
+        "read",
+        "/Library/Preferences/com.apple.loginwindow.plist",
+        "autoLoginUser",
+    ]
+    ret = __salt__["cmd.run_all"](cmd, ignore_retcode=True)
+    return False if ret["retcode"] else ret["stdout"]
 
 
 def _kcpassword(password):
-    '''
+    """
     Internal function for obfuscating the password used for AutoLogin
     This is later written as the contents of the ``/etc/kcpassword`` file
 
@@ -543,7 +533,7 @@ def _kcpassword(password):
 
     Returns:
         str: The obfuscated password
-    '''
+    """
     # The magic 11 bytes - these are just repeated
     # 0x7D 0x89 0x52 0x23 0xD2 0xBC 0xDD 0xEA 0xA3 0xB9 0x1F
     key = [125, 137, 82, 35, 210, 188, 221, 234, 163, 185, 31]
@@ -566,18 +556,19 @@ def _kcpassword(password):
         # corresponding item in the key
         # The length of the password, or the length of the key, whichever is
         # smaller
-        for password_index in range(chunk_index,
-                                    min(chunk_index + len(key), len(password))):
+        for password_index in range(
+            chunk_index, min(chunk_index + len(key), len(password))
+        ):
             password[password_index] = password[password_index] ^ key[key_index]
             key_index += 1
 
     # Convert each byte back to a character
     password = list(map(chr, password))
-    return b''.join(salt.utils.data.encode(password))
+    return b"".join(salt.utils.data.encode(password))
 
 
 def enable_auto_login(name, password):
-    '''
+    """
     .. versionadded:: 2016.3.0
 
     Configures the machine to auto login with the specified user
@@ -598,27 +589,29 @@ def enable_auto_login(name, password):
     .. code-block:: bash
 
         salt '*' user.enable_auto_login stevej
-    '''
+    """
     # Make the entry into the defaults file
-    cmd = ['defaults',
-           'write',
-           '/Library/Preferences/com.apple.loginwindow.plist',
-           'autoLoginUser',
-           name]
-    __salt__['cmd.run'](cmd)
+    cmd = [
+        "defaults",
+        "write",
+        "/Library/Preferences/com.apple.loginwindow.plist",
+        "autoLoginUser",
+        name,
+    ]
+    __salt__["cmd.run"](cmd)
     current = get_auto_login()
 
     # Create/Update the kcpassword file with an obfuscated password
     o_password = _kcpassword(password=password)
     with salt.utils.files.set_umask(0o077):
-        with salt.utils.files.fopen('/etc/kcpassword', 'w' if six.PY2 else 'wb') as fd:
+        with salt.utils.files.fopen("/etc/kcpassword", "w" if six.PY2 else "wb") as fd:
             fd.write(o_password)
 
     return current if isinstance(current, bool) else current.lower() == name.lower()
 
 
 def disable_auto_login():
-    '''
+    """
     .. versionadded:: 2016.3.0
 
     Disables auto login on the machine
@@ -631,15 +624,17 @@ def disable_auto_login():
     .. code-block:: bash
 
         salt '*' user.disable_auto_login
-    '''
+    """
     # Remove the kcpassword file
-    cmd = 'rm -f /etc/kcpassword'
-    __salt__['cmd.run'](cmd)
+    cmd = "rm -f /etc/kcpassword"
+    __salt__["cmd.run"](cmd)
 
     # Remove the entry from the defaults file
-    cmd = ['defaults',
-           'delete',
-           '/Library/Preferences/com.apple.loginwindow.plist',
-           'autoLoginUser']
-    __salt__['cmd.run'](cmd)
+    cmd = [
+        "defaults",
+        "delete",
+        "/Library/Preferences/com.apple.loginwindow.plist",
+        "autoLoginUser",
+    ]
+    __salt__["cmd.run"](cmd)
     return True if not get_auto_login() else False
