@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-'''
+"""
     :codeauthor: Pedro Algarvio (pedro@algarvio.me)
 
     tests.support.mock
@@ -11,89 +11,50 @@
 
     Note: mock >= 2.0.0 required since unittest.mock does not have
     MagicMock.assert_called in Python < 3.6.
-'''
+"""
 # pylint: disable=unused-import,function-redefined,blacklisted-module,blacklisted-external-module
 
 from __future__ import absolute_import
+
 import collections
 import copy
 import errno
 import fnmatch
 import sys
 
-# Import salt libs
-from salt.ext import six
+# By these days, we should blowup if mock is not available
+import mock  # pylint: disable=blacklisted-external-import
 import salt.utils.stringutils
 
-try:
-    from mock import (
-        Mock,
-        MagicMock,
-        patch,
-        sentinel,
-        DEFAULT,
-        # ANY and call will be imported further down
-        create_autospec,
-        FILTER_DIR,
-        NonCallableMock,
-        NonCallableMagicMock,
-        PropertyMock,
-        __version__
-    )
-    NO_MOCK = False
-    NO_MOCK_REASON = ''
-    mock_version = []
-    for __part in __version__.split('.'):
-        try:
-            mock_version.append(int(__part))
-        except ValueError:
-            # Non-integer value (ex. '1a')
-            mock_version.append(__part)
-    mock_version = tuple(mock_version)
-except ImportError as exc:
-    NO_MOCK = True
-    NO_MOCK_REASON = 'mock python module is unavailable'
-    mock_version = (0, 0, 0)
+# pylint: disable=no-name-in-module,no-member
+from mock import (
+    ANY,
+    DEFAULT,
+    FILTER_DIR,
+    MagicMock,
+    Mock,
+    NonCallableMagicMock,
+    NonCallableMock,
+    PropertyMock,
+    __version__,
+    call,
+    create_autospec,
+    patch,
+    sentinel,
+)
 
-    # Let's not fail on imports by providing fake objects and classes
+# Import salt libs
+from salt.ext import six
 
-    class MagicMock(object):
-
-        # __name__ can't be assigned a unicode
-        __name__ = str('{0}.fakemock').format(__name__)  # future lint: disable=blacklisted-function
-
-        def __init__(self, *args, **kwargs):
-            pass
-
-        def dict(self, *args, **kwargs):
-            return self
-
-        def multiple(self, *args, **kwargs):
-            return self
-
-        def __call__(self, *args, **kwargs):
-            return self
-
-    Mock = MagicMock
-    patch = MagicMock()
-    sentinel = object()
-    DEFAULT = object()
-    create_autospec = MagicMock()
-    FILTER_DIR = True
-    NonCallableMock = MagicMock()
-    NonCallableMagicMock = MagicMock()
-    mock_open = object()
-    PropertyMock = object()
-    call = tuple
-    ANY = object()
+# pylint: disable=no-name-in-module,no-member
 
 
-if NO_MOCK is False:
-    try:
-        from mock import call, ANY
-    except ImportError:
-        NO_MOCK = True
-        NO_MOCK_REASON = 'you need to upgrade your mock version to >= 0.8.0'
+__mock_version = tuple(
+    [int(part) for part in mock.__version__.split(".") if part.isdigit()]
+)  # pylint: disable=no-member
+if sys.version_info < (3, 6) and __mock_version < (2,):
+    # We need mock >= 2.0.0 before Py3.6
+    raise ImportError("Please install mock>=2.0.0")
 
 
 class MockFH(object):
@@ -103,11 +64,11 @@ class MockFH(object):
         try:
             self.mode = args[0]
         except IndexError:
-            self.mode = kwargs.get('mode', 'r')
-        self.binary_mode = 'b' in self.mode
-        self.read_mode = any(x in self.mode for x in ('r', '+'))
-        self.write_mode = any(x in self.mode for x in ('w', 'a', '+'))
-        self.empty_string = b'' if self.binary_mode else ''
+            self.mode = kwargs.get("mode", "r")
+        self.binary_mode = "b" in self.mode
+        self.read_mode = any(x in self.mode for x in ("r", "+"))
+        self.write_mode = any(x in self.mode for x in ("w", "a", "+"))
+        self.empty_string = b"" if self.binary_mode else ""
         self.call = MockCall(filename, *args, **kwargs)
         self.read_data_iter = self._iterate_read_data(read_data)
         self.read = Mock(side_effect=self._read)
@@ -121,14 +82,14 @@ class MockFH(object):
         self.__read_data_ok = False
 
     def _iterate_read_data(self, read_data):
-        '''
+        """
         Helper for mock_open:
         Retrieve lines from read_data via a generator so that separate calls to
         readline, read, and readlines are properly interleaved
-        '''
+        """
         # Newline will always be a bytestring on PY2 because mock_open will have
         # normalized it to one.
-        newline = b'\n' if isinstance(read_data, six.binary_type) else '\n'
+        newline = b"\n" if isinstance(read_data, six.binary_type) else "\n"
 
         read_data = [line + newline for line in read_data.split(newline)]
 
@@ -147,16 +108,16 @@ class MockFH(object):
 
     @property
     def write_calls(self):
-        '''
+        """
         Return a list of all calls to the .write() mock
-        '''
+        """
         return [x[1][0] for x in self.write.mock_calls]
 
     @property
     def writelines_calls(self):
-        '''
+        """
         Return a list of all calls to the .writelines() mock
-        '''
+        """
         return [x[1][0] for x in self.writelines.mock_calls]
 
     def tell(self):
@@ -167,19 +128,17 @@ class MockFH(object):
             if self.binary_mode:
                 if not isinstance(self.read_data, six.binary_type):
                     raise TypeError(
-                        '{0} opened in binary mode, expected read_data to be '
-                        'bytes, not {1}'.format(
-                            self.filename,
-                            type(self.read_data).__name__
+                        "{0} opened in binary mode, expected read_data to be "
+                        "bytes, not {1}".format(
+                            self.filename, type(self.read_data).__name__
                         )
                     )
             else:
                 if not isinstance(self.read_data, str):
                     raise TypeError(
-                        '{0} opened in non-binary mode, expected read_data to '
-                        'be str, not {1}'.format(
-                            self.filename,
-                            type(self.read_data).__name__
+                        "{0} opened in non-binary mode, expected read_data to "
+                        "be str, not {1}".format(
+                            self.filename, type(self.read_data).__name__
                         )
                     )
             # No need to repeat this the next time we check
@@ -188,9 +147,9 @@ class MockFH(object):
     def _read(self, size=0):
         self.__check_read_data()
         if not self.read_mode:
-            raise IOError('File not open for reading')
+            raise IOError("File not open for reading")
         if not isinstance(size, six.integer_types) or size < 0:
-            raise TypeError('a positive integer is required')
+            raise TypeError("a positive integer is required")
 
         joined = self.empty_string.join(self.read_data_iter)
         if not size:
@@ -210,7 +169,7 @@ class MockFH(object):
         # TODO: Implement "size" argument
         self.__check_read_data()
         if not self.read_mode:
-            raise IOError('File not open for reading')
+            raise IOError("File not open for reading")
         ret = list(self.read_data_iter)
         self.__loc += sum(len(x) for x in ret)
         return ret
@@ -219,7 +178,7 @@ class MockFH(object):
         # TODO: Implement "size" argument
         self.__check_read_data()
         if not self.read_mode:
-            raise IOError('File not open for reading')
+            raise IOError("File not open for reading")
         try:
             ret = next(self.read_data_iter)
             self.__loc += len(ret)
@@ -230,7 +189,7 @@ class MockFH(object):
     def __iter__(self):
         self.__check_read_data()
         if not self.read_mode:
-            raise IOError('File not open for reading')
+            raise IOError("File not open for reading")
         while True:
             try:
                 ret = next(self.read_data_iter)
@@ -241,7 +200,7 @@ class MockFH(object):
 
     def _write(self, content):
         if not self.write_mode:
-            raise IOError('File not open for writing')
+            raise IOError("File not open for writing")
         if six.PY2:
             if isinstance(content, six.text_type):
                 # encoding intentionally not specified to force a
@@ -251,20 +210,20 @@ class MockFH(object):
             content_type = type(content)
             if self.binary_mode and content_type is not bytes:
                 raise TypeError(
-                    'a bytes-like object is required, not \'{0}\''.format(
+                    "a bytes-like object is required, not '{0}'".format(
                         content_type.__name__
                     )
                 )
             elif not self.binary_mode and content_type is not str:
                 raise TypeError(
-                    'write() argument must be str, not {0}'.format(
+                    "write() argument must be str, not {0}".format(
                         content_type.__name__
                     )
                 )
 
     def _writelines(self, lines):
         if not self.write_mode:
-            raise IOError('File not open for writing')
+            raise IOError("File not open for writing")
         for line in lines:
             self._write(line)
 
@@ -282,20 +241,19 @@ class MockCall(object):
 
     def __repr__(self):
         # future lint: disable=blacklisted-function
-        ret = str('MockCall(')
+        ret = str("MockCall(")
         for arg in self.args:
-            ret += repr(arg) + str(', ')
+            ret += repr(arg) + str(", ")
         if not self.kwargs:
             if self.args:
                 # Remove trailing ', '
                 ret = ret[:-2]
         else:
             for key, val in six.iteritems(self.kwargs):
-                ret += str('{0}={1}').format(
-                    salt.utils.stringutils.to_str(key),
-                    repr(val)
+                ret += str("{0}={1}").format(
+                    salt.utils.stringutils.to_str(key), repr(val)
                 )
-        ret += str(')')
+        ret += str(")")
         return ret
         # future lint: enable=blacklisted-function
 
@@ -406,7 +364,8 @@ class MockOpen(object):
     * filehandles - This is a dictionary mapping filenames to lists of MockFH
       objects, representing the individual times that a given file was opened.
     '''
-    def __init__(self, read_data=''):
+
+    def __init__(self, read_data=""):
         # If the read_data contains lists, we will be popping it. So, don't
         # modify the original value passed.
         read_data = copy.copy(read_data)
@@ -414,7 +373,7 @@ class MockOpen(object):
         # Normalize read_data, Python 2 filehandles should never produce unicode
         # types on read.
         if not isinstance(read_data, dict):
-            read_data = {'*': read_data}
+            read_data = {"*": read_data}
 
         if six.PY2:
             # .__class__() used here to preserve the dict class in the event that
@@ -437,22 +396,22 @@ class MockOpen(object):
         self.call_count = 0
 
     def __call__(self, name, *args, **kwargs):
-        '''
+        """
         Match the file being opened to the patterns in the read_data and spawn
         a mocked filehandle with the corresponding file contents.
-        '''
+        """
         call = MockCall(name, *args, **kwargs)
         self.calls.append(call)
         self.call_count += 1
         for pat in self.read_data:
-            if pat == '*':
+            if pat == "*":
                 continue
             if fnmatch.fnmatch(name, pat):
                 matched_pattern = pat
                 break
         else:
             # No non-glob match in read_data, fall back to '*'
-            matched_pattern = '*'
+            matched_pattern = "*"
         try:
             matched_contents = self.read_data[matched_pattern]
             try:
@@ -465,8 +424,8 @@ class MockOpen(object):
             except IndexError:
                 # We've run out of file contents, abort!
                 raise RuntimeError(
-                    'File matching expression \'{0}\' opened more times than '
-                    'expected'.format(matched_pattern)
+                    "File matching expression '{0}' opened more times than "
+                    "expected".format(matched_pattern)
                 )
 
             try:
@@ -484,13 +443,13 @@ class MockOpen(object):
         except KeyError:
             # No matching glob in read_data, treat this as a file that does
             # not exist and raise the appropriate exception.
-            raise IOError(errno.ENOENT, 'No such file or directory', name)
+            raise IOError(errno.ENOENT, "No such file or directory", name)
 
     def write_calls(self, path=None):
-        '''
+        """
         Returns the contents passed to all .write() calls. Use `path` to narrow
         the results to files matching a given pattern.
-        '''
+        """
         ret = []
         for filename, handles in six.iteritems(self.filehandles):
             if path is None or fnmatch.fnmatch(filename, path):
@@ -499,10 +458,10 @@ class MockOpen(object):
         return ret
 
     def writelines_calls(self, path=None):
-        '''
+        """
         Returns the contents passed to all .writelines() calls. Use `path` to
         narrow the results to files matching a given pattern.
-        '''
+        """
         ret = []
         for filename, handles in six.iteritems(self.filehandles):
             if path is None or fnmatch.fnmatch(filename, path):
@@ -511,5 +470,40 @@ class MockOpen(object):
         return ret
 
 
+class MockTimedProc(object):
+    """
+    Class used as a stand-in for salt.utils.timed_subprocess.TimedProc
+    """
+
+    class _Process(object):
+        """
+        Used to provide a dummy "process" attribute
+        """
+
+        def __init__(self, returncode=0, pid=12345):
+            self.returncode = returncode
+            self.pid = pid
+
+    def __init__(self, stdout=None, stderr=None, returncode=0, pid=12345):
+        if stdout is not None and not isinstance(stdout, bytes):
+            raise TypeError("Must pass stdout to MockTimedProc as bytes")
+        if stderr is not None and not isinstance(stderr, bytes):
+            raise TypeError("Must pass stderr to MockTimedProc as bytes")
+        self._stdout = stdout
+        self._stderr = stderr
+        self.process = self._Process(returncode=returncode, pid=pid)
+
+    def run(self):
+        pass
+
+    @property
+    def stdout(self):
+        return self._stdout
+
+    @property
+    def stderr(self):
+        return self._stderr
+
+
 # reimplement mock_open to support multiple filehandles
 mock_open = MockOpen
